@@ -1,6 +1,6 @@
 # pyenchant
 #
-# Copyright (C) 2004-2008 Ryan Kelly
+# Copyright (C) 2004-2011 Ryan Kelly
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -29,7 +29,8 @@
 #
 """
 
-  pypwl:  pure-python personal word list in the style of Enchant
+pypwl:  pure-python personal word list in the style of Enchant
+==============================================================
 
 This module provides a pure-python version of the personal word list
 functionality found in the spellchecking package Enchant.  While the
@@ -45,6 +46,7 @@ prototype for the C version found in Enchant).
 from __future__ import generators
 
 import os
+import warnings
 
 class Trie:
     """Class implementing a trie-based dictionary of words.
@@ -227,7 +229,7 @@ class PyPWL:
         For a PWL, this means appending it to the file.
         """
         warnings.warn("PyPWL.add_to_pwl is deprecated, please use PyPWL.add",
-                      category=DeprecationWarning)
+                      category=DeprecationWarning,stacklevel=2)
         self.add(word)
 
     def remove(self,word):
